ASN Check
=========

Given a list of IPs the tool returns their ASN numbers and names.

Data sources:
  - [ASN ranges - Thyme APNIC](https://thyme.apnic.net/current/data-raw-table)
  - [ASN names - ripe.net](https://ftp.ripe.net/ripe/asnames/asn.txt)


